packer {
  required_plugins {
  }
}

build {
  source "vsphere-iso.ubuntu" {
    name = "bootstrap"
    vm_name = "bld_${var.vm_name}_bootstrap"
  }

  source "vsphere-iso.ubuntu" {
    name = "upgrade"
    vm_name = "bld_${var.vm_name}_upgrade"
  }

  provisioner "ansible" {
    pause_before     = "45s"

    playbook_file    = "ansible/playbook.yml"
    user             = "ubuntu"
    ansible_env_vars = [
      "ANSIBLE_CONFIG=ansible/ansible.cfg",
      "PYTHONUNBUFFERED=1"
    ]
    use_proxy        = "false"
    collections_path = "ansible/collections"

    extra_arguments  = [
      "--extra-vars", "appliancetype=${source.name}",
      "--extra-vars", "ansible_ssh_pass=${var.ssh_password}",
      "--extra-vars", "docker_username=${var.docker_username}",
      "--extra-vars", "docker_password=${var.docker_password}",
      "--extra-vars", "repo_username=${var.repo_username}",
      "--extra-vars", "repo_password=${var.repo_password}"
    ]
  }

  post-processor "shell-local" {
    inline = [
      "pwsh -command \"& scripts/Update-OvfConfiguration.ps1 \\",
      " -ApplianceType '${source.name}' \\",
      " -OVFFile '/scratch/bld_${var.vm_name}_${source.name}.ovf' \"",
      "pwsh -file scripts/Update-Manifest.ps1 \\",
      " -ManifestFileName '/scratch/bld_${var.vm_name}_${source.name}.mf'",
      "ovftool --acceptAllEulas --allowExtraConfig --overwrite \\",
      " '/scratch/bld_${var.vm_name}_${source.name}.ovf' \\",
      " /output/airgapped-k8s-${var.k8s_version}.${source.name}.ova"
    ]
  }
}
